#!/bin/sh


##        Licensed Materials - Property of IBM
##        (C) Copyright IBM Corp. 2000, 2002 All Rights Reserved 
##
##       US Government Users Restricted Rights - Use, duplication,
##       or disclosure restricted by GSA ADP Schedule Contract with
##       IBM Corp.
##
##   TFST 1.3 - event sink upgrade script
##


version="1.3"
instance="eventsink"
repository_dir="/etc/Tivoli/TFST/$version/installed"

if echo -n | egrep -e -n >/dev/null ; then
    dashn=""
else
    dashn=-n
fi



print_os_name()
{
	if [ -f /bin/sun ] && /bin/sun ; then
		echo solaris
	elif [ `uname` = "AIX" ] ; then
		echo aix
	elif [ `uname` = "HP-UX" ] ; then
		echo hpux
	else
		if [ `uname` = "Linux" ] ; then
			echo linux
		else
			uname
		fi
	fi
}


check_response()
{
	read ans

	if [ X${ans} = Xy ] || [ X${ans} = XY ] ||
         [ X${ans} = Xyes ] || [ X${ans} = XYES ] ||
         [ "$1" = "Y" -a X${ans} = X ] ; then
		return 0
	fi

	return 1
}

check_path()
{
	if [ ! -d $1 ] ; then
		return 1
	fi

	if [ ! -f "$1/eventsink" ] ; then
		return 1
	fi

	if [ ! -f "$1/eventsink.cfg" ] ; then
		return 1
	fi

	return 0
}

check_installed()
{
	installed_file=$repository_dir/$instance
	
	# check if the installation repository directory exists
	if [ ! -d $repository_dir ] ; then
		return 0;
	fi

	if [ ! -f $installed_file ] ; then
		return 0
	fi

	return 1
}

auto_start_remove()
{
OSNAME=`print_os_name`

case "$OSNAME" in
	aix)
		RCFILE=/etc/rc.$instance
		RCTAB=$instance

        set e+

		if [ -f $RCFILE ] ; then
			rm -rf $RCFILE
        fi

        rmitab $RCTAB

		set -e
	    ;;

	*)
	    for dir in /etc/rc.d/init.d /etc/init.d /usr/sbin/init.d /sbin/init.d; do
	        [ -d $dir ] && MRCD=$dir
	    done

	    rm -f $MRCD/$instance*
	    if [ -d /var/lock/subsys ]; then
		rm -f /var/lock/subsys/$instance
	    fi

	    find /etc/rc* -name S*$instance -exec rm {} \;
	    find /etc/rc* -name K*$instance -exec rm {} \;
	    
    esac

    return 0
}

################################################
#
#    install script starts here
#
################################################

clear
work_dir=`pwd`

#
# check platform
#
os_name=`print_os_name`
if [ X${os_name} != Xhpux ] && [ X${os_name} != Xaix ] && [ X${os_name} != Xsolaris ] && [ X${os_name} != Xlinux ] ; then
	echo "Platform $os_name is not supported."
	exit 1
fi

#
# ask for license agreement 
#
ok=0
while [ $ok = 0 ] ; do
	echo "To install the Tivoli Event Sink, you must accept the agreement written in the License file."
	echo $dashn "If you accept the agreement, enter Y.  [Y/N]: "
	read ans

	if [ X${ans} = Xy ] || [ X${ans} = XY ] ||
         [ X${ans} = Xyes ] || [ X${ans} = XYES ] ; then
		ok=1
	fi

	if [ X${ans} = Xn ] || [ X${ans} = XN ] ||
         [ X${ans} = Xno ] || [ X${ans} = XNO ] ; then
		exit 1
	fi
done

#
# check if the 1.3 is already installed 
#
check_installed;
if [ $? = 1 ] ; then
	echo $dashn "Event Sink 1.3 is already installed."
	exit 1
fi

#
# ask for installation directory
#
ok=0
while [ $ok = 0 ] ; do
	echo $dashn "Event Sink 1.2 installation directory: "
	read ans
	if [ X${ans} != X ] ; then
		# check if the path exists
		try_path=${ans}
		check_path ${try_path}
		if [ $? != 0 ] ; then
			echo $dashn "The event sink was not found in the directory: $try_path"
		else
			install_dir=${try_path}
			ok=1
		fi
	fi
done

#
# get the user name
#
username=`ls -l $install_dir/eventsink | awk '{ print $3 }'`
if [ X${username} = X ] ; then
	echo $dashn "Unable to identify the user of the directory you specified."
	exit 1
fi

#
# ask for upgrade confirmation
#
ok=0
while [ $ok = 0 ] ; do
	echo
	echo "A previous version of the event sink has been detected on the machine."
	echo "The configuration and all the data of the previous version will be backed up to '${install_dir}.1.2'."
	echo "It will be used by the new version."
	echo "Do you want upgrade to the new version? [Y/N] "
	read ans

	if [ X${ans} = Xy ] || [ X${ans} = XY ] ||
         [ X${ans} = Xyes ] || [ X${ans} = XYES ] ; then
		ok=1
	fi

	if [ X${ans} = Xn ] || [ X${ans} = XN ] ||
         [ X${ans} = Xno ] || [ X${ans} = XNO ] ; then
		exit 1
	fi
done

#
# backup the 1.2 stuff
#
if [ -d "${install_dir}.1.2" ] ; then
	rm -rf "${install_dir}.1.2"
fi
cp -rf ${install_dir} "${install_dir}.1.2"

#
# remove 1.2 stuff (except of cfg)
#
$install_dir/eventsink.sh stop > /dev/null

lcf_datdir=`grep '^LCF_DATDIR=' $install_dir/eventsink.sh | sed -e 's/.*=//' -e 's/"//g'`

rm -f $install_dir/eventsink
rm -f $install_dir/*.log
rm -f $install_dir/*.pid
rm -f $install_dir/eventsink.sh
rm -f $install_dir/C/*
rmdir $install_dir/C
auto_start_remove

#
# launch the silent install
#
./install.sh -s ${install_dir} ${username} ${lcf_datdir}

echo "Event sink successfully upgraded."

#
# ask for event sink start-up
#
ok=0
default="Y"
while [ $ok = 0 ] ; do
	echo $dashn "Start the event sink? [Y/N] [default=$default]: "
	check_response $default
	if [ $? = 0 ] ; then
		nohup ${install_dir}/eventsink.sh start 1>/dev/null 2>&1 &
	else
		echo "Event sink not started"
	fi
	ok=1
done

